@@ -78,19 +78,24 @@ def configure_log():
         level=logging.DEBUG,
         filemode='w')
 
-def get_from_args_or_environment(arg_pos, env_variable_name, args):
-    """Gets the argument from the position specified or gets the environment variable name passed.
+def get_from_vars_or_args_or_environment(arg_pos, variable_name, vars, args):
+    """Gets the argument from the position specified or gets the value from the table vars or gets the environment variable name passed.
 
         arg_pos
             The argument position to be used from the arguments parameter.
-        env_variable_name
-            The name of the environment variable to be obtained.
+        variable_name
+            The name of the variable to be obtained.
+        vars
+            The hash with the variables names and values.
         args
             The arguments array parameter.
     """
     if (arg_pos < len(args)):
         return args[arg_pos]
-    env_value = getenv(env_variable_name)
+    var_value = vars.get(variable_name, None)
+    if (var_value is not None):
+        return var_value
+    env_value = getenv(variable_name)
     return env_value
 
 def get_argkey(astr):
@@ -133,9 +138,26 @@ def read_param_args(args):
         if len(dictionary) != 0:
             has_passed_variables = True
             print("Using variables")
-            print(dictionary)
+            print_table(dictionary)
     return dictionary
 
+def print_table(dictionary):
+    """
+    Prints the dictionary without exposing user and password values
+    """
+    length = len(dictionary)
+    i = 0
+    terminator = ', '
+    print("{", end='')
+    for key,value in dictionary.items():
+        if ("PASSWORD" in key or "USER" in key):
+            value = "*" * 12
+        i += 1
+        if (i == length) :
+            terminator = ''
+        print(f"'{key}':'{value}'", end=terminator)
+    print("}")
+
 def expandvars(path, params, skip_escaped=False):
     """Expand environment variables of form $var and ${var}.
        If parameter 'skip_escaped' is True, all escaped variable references
@@ -198,21 +220,24 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
     """
     global error_code
     global opened_connections
+    print("arguments: ", sys.argv)
     # exclude arguments passed inline to the script
     args = [item for item in sys.argv if not item.startswith("--param-")]
     if (user is None):
-        user = get_from_args_or_environment(1, "SNOW_USER", args)
+        user = get_from_vars_or_args_or_environment(1, "SNOW_USER", passed_variables, args)
     if (password is None):
-        password = get_from_args_or_environment(2, "SNOW_PASSWORD", args)
+        password = get_from_vars_or_args_or_environment(2, "SNOW_PASSWORD", passed_variables, args)
     if (account is None):
-        account = get_from_args_or_environment(3, "SNOW_ACCOUNT", args)
+        account = get_from_vars_or_args_or_environment(3, "SNOW_ACCOUNT", passed_variables, args)
     if (database is None):
-        database = get_from_args_or_environment(4, "SNOW_DATABASE", args)
+        database = get_from_vars_or_args_or_environment(4, "SNOW_DATABASE", passed_variables, args)
     if (warehouse is None):
-        warehouse = get_from_args_or_environment(5, "SNOW_WAREHOUSE", args)
+        warehouse = get_from_vars_or_args_or_environment(5, "SNOW_WAREHOUSE", passed_variables, args)
     if (role is None):
-        role = get_from_args_or_environment(6, "SNOW_ROLE", args)
-    query_tag = getenv("SNOW_QUERYTAG", None)
+        role = get_from_vars_or_args_or_environment(6, "SNOW_ROLE", passed_variables, args)
+    query_tag = passed_variables.get("SNOW_QUERYTAG", None)
+    if (query_tag is None):
+        query_tag = getenv("SNOW_QUERYTAG", None)
     if query_tag is None:
         frm = inspect.stack()[1]
         query_tag = path.basename(frm.filename)
@@ -305,6 +330,7 @@ def exec(sql_string, using=None, con=None):
     global current_error_count
     global max_errors
     global error_code
+    global _previous_executed_sql
     if (con is None):
         # get last connection
         con = opened_connections[-1]
@@ -330,7 +356,7 @@ def exec(sql_string, using=None, con=None):
                 _print_result_set(cur)
     except snowflake.connector.errors.ProgrammingError as e:
         current_error_count = current_error_count + 1
-        _handle_syntax_error(e)
+        _handle_syntax_error(e, sql_string)
     except: # catch *all* exceptions
         current_error_count = current_error_count + 1
         e = sys.exc_info()
@@ -382,7 +408,7 @@ def _print_result_set(cur):
                     rowval = Export.separator.join([str(val) for val in row])
                     print(rowval, file=f)
 
-def _handle_syntax_error(e):
+def _handle_syntax_error(e, sql_string):
     if "syntax error" in e.msg:
         regex = r"syntax error line (\d+) at position (\d+)"
         matches = re.finditer(regex, e.msg, re.MULTILINE)
@@ -447,6 +473,26 @@ def readrun(line, skip=0):
     else:
         return []
 
+def exec_file(filename, con=None):
+    """Reads the content of a file and executes the sql statements contained 
+    with the specified connection
+
+        filename
+            The filename to be read and executed
+        con=None
+            The connection to be used, if None is passed it will use the last
+            connection performed
+    """
+    expandedpath = path.expandvars(filename)
+    if path.isfile(expandedpath):
+        with open(expandedpath, 'r') as f:
+            contents = f.read()
+            statements = contents.split(";")
+            for statement in statements:
+                exec(statement, con=con)
+    else:
+        print(colored("*** Error: File does not exist", 'red'))
+
 def remark(arg):
     """Prints the argument.
 
@@ -642,6 +688,7 @@ class Import:
     no_more_rows = False
     read_obj = None
 
+    @staticmethod
     def file(file, separator=' '):
         Import.separator = separator
         Import.expandedfilename = path.expandvars(file)
@@ -651,6 +698,7 @@ class Import:
         Import.read_obj = None
         Import.no_more_rows = False
 
+    @staticmethod
     def using(globals, *argv):
         print (argv)
         try:
@@ -707,33 +755,86 @@ class Import:
             Import.expandedfilename = None
             Import.separator = ' '
 
-Import.file = staticmethod(Import.file)
-Import.using = staticmethod(Import.using)    
-
 class Export:
     expandedfilename = None
     separator = ' '
+    _record_mode = False
+    _separator_width = 2
+    _side_titles = False
+    _title_dashes = False
+    _title_dashes_with = 0
+    _width = 80
+    _null = '?'
+
+    @staticmethod
+    def defaults():
+        Export.reset()
+
+    @staticmethod
+    def null(value = None):
+        if value is not None:
+            Export._null = value
+        return Export._null
+
+    @staticmethod
+    def record_mode(value = None):
+        if value is not None:
+            Export._record_mode = value
+        return Export._record_mode
+
+    @staticmethod
     def report(file, separator=' '):
         Export.separator = separator
         Export.expandedfilename = path.expandvars(file)
+
     @staticmethod
-    @deprecated(reason="This function will be removed soon", version='1.9')
-    def title_dashes(state="ON", withValue=None):
-        pass
-    @staticmethod
-    @deprecated(reason="This function will be removed soon", version='1.9')
-    def width(width):
-        pass
-    @staticmethod
-    @deprecated(reason="This function will be removed soon", version='1.9')
     def reset():
         Export.expandedfilename = None
-        Export.separator = ' '
+        Export.record_mode(False)
+        Export.title_dashes(False, 0)
+        Export.side_titles(False)
+        Export.separator_string(' ')
+        Export.separator_width(2)
+        Export.width(80)
+        Export.null('?')
 
-Export.title_dashes = staticmethod(Export.title_dashes)
-Export.reset = staticmethod(Export.reset)
-Export.report = staticmethod(Export.report)
-Export.width = staticmethod(Export.width)
+    @staticmethod
+    def separator_string(value = None):
+        if (value is not None):
+            Export.separator = value
+        return Export.separator
+
+    @staticmethod
+    def separator_width(value = None):
+        if (value is not None):
+            Export._separator_width = value
+        return Export._separator_width
+
+    @staticmethod
+    def side_titles(value = None):
+        if value is not None:
+            Export._side_titles = value
+        return Export._side_titles
+
+    @staticmethod
+    def title_dashes(value = None, withValue = None):
+        if value is not None:
+            Export._title_dashes = value
+        if withValue is not None:
+            Export.title_dashes_with(withValue)
+        return Export._title_dashes
+    
+    @staticmethod
+    def title_dashes_with(value = None):
+        if value is not None:
+            Export._title_dashes_with = value
+        return Export._title_dashes_with
+
+    @staticmethod
+    def width(value = None):
+        if value is not None:
+            Export._width = value
+        return Export._width
 
 class Parameters:
     passed_variables = {}
